VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package ife

Package {ife}


Type: Package
Title: Autodiff for Influence Function Based Estimates
Version: 0.2.3
Maintainer: Nicholas Williams <ntwilliams.personal@gmail.com>
Description: Implements an S7 class for estimates based on influence functions, with forward mode automatic differentiation defined for standard arithmetic operations.
License: GPL (≥ 3)
Encoding: UTF-8
URL: https://github.com/nt-williams/ife
BugReports: https://github.com/nt-williams/ife/issues
Imports: cli, collapse, generics, S7 (≥ 0.2.0)
RoxygenNote: 7.3.2
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-02-06 23:03:29 UTC; nicholaswilliams
Author: Nicholas Williams ORCID iD [aut, cre, cph]
Repository: CRAN
Date/Publication: 2026-02-07 06:10:30 UTC

Create a new 'influence_func_estimate' object

Description

Create a new 'influence_func_estimate' object

Usage

ife(
  x,
  eif,
  weights = rep(1, length(eif)),
  id = as.character(1:length(eif)),
  critical_value = qnorm(0.975)
)

influence_func_estimate(
  x,
  eif,
  weights = rep(1, length(eif)),
  id = as.character(1:length(eif)),
  critical_value = qnorm(0.975)
)

Arguments

x

[numeric(1)]
The estimate.

eif

[numeric(n)]
The influence function.

weights

[numeric(n)]
Optional sampling weights.

id

[character(n)]
Optional cluster identifiers.

critical_value

[numeric(1)]
Optional critical value for constructing confidence interval.

Value

An 'S7' object of class influence_func_estimate.

Examples

x <- influence_func_estimate(5, runif(10))
y <- ife(5, runif(10))
x + y
x + 1
1 - y
x / y
x * y
tidy(x)
# Example: Confidence interval for a variance estimate
x <- rnorm(100, 0, 2)
ife(mean(x^2), x^2 - mean(x^2)) - ife(mean(x), x - mean(x))^2

Objects exported from other packages

Description

These objects are imported from other packages. Follow the links below to see their documentation.

generics

tidy

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.